@@ -4,9 +4,11 @@
 #include <QWidget>
 #include "route.h"
 #include "transport.h"
+#include "coordinates.h"
 #include "stop.h"
 
 #include <QPixmap>
+#include <QDateTime>
 #include <QList>
 
 class QPushButton;
@@ -22,7 +24,7 @@ public:
     
     ~displayInfoWidget();
 
-    void setRoute(const Route &ruta);
+    void setRoute(const Route &ruta, int id);
 
     void displayTransport(const Transport &trans);
     
@@ -40,7 +42,7 @@ public:
 
 signals:
 
-    void clicked();
+    void clicked(int);
 
 public slots:
 
@@ -49,6 +51,8 @@ public slots:
 private slots:
     
     void displayStops();
+    
+    void setAlarm();
 
 private:
 
@@ -63,6 +67,10 @@ private:
     Stop::List mStops;
     QList<QWidget*>  mWidgets;
     int state;
+    //For stops
+    Coordinates mLocation;
+    QDateTime mTime;
+    int mId;
 
 
 };
