@@ -1,5 +1,5 @@
-#ifndef ROUTEWINDOW_H
-#define ROUTEWINDOW_H
+#ifndef INFOWINDOW_H
+#define INFOWINDOW_H
 
 #include <QWidget>
 #include <QScrollArea>
@@ -10,14 +10,15 @@
 class QScrollArea;
 class QVBoxLayout;
 
-class RouteWindow : public QScrollArea
+class InfoWindow : public QScrollArea
 {
 Q_OBJECT
 public:
-    explicit RouteWindow();
+    explicit InfoWindow();
     
-    explicit RouteWindow( Route route, QWidget *parent = 0);
-
+    explicit InfoWindow( Route route, QWidget *parent = 0);
+    
+    explicit InfoWindow( const Route::List &routes, QWidget *parent = 0);
     
     void setRoute(Route route);
     
@@ -26,6 +27,8 @@ public:
 signals:
 
 public slots:
+    
+    void elementClicked(int);
 
 protected:
         virtual bool event( QEvent *event);
@@ -35,7 +38,8 @@ private:
     Route mRoute;
     QVBoxLayout *mLayout;
     QWidgetList mList;
+    const Route::List &mRoutes;
     
 };
 
-#endif // ROUTEWINDOW_H
+#endif // INFOWINDOW_H
