@@ -39,9 +39,9 @@ bool Ytv::reverseGeoCode(const float x, const float y) {
 
 }
 
-bool Ytv::route(FinnishCoordinates start, FinnishCoordinates dest, const QDateTime &datetime) {
+bool Ytv::route(FinnishCoordinates start, FinnishCoordinates dest, const QDateTime &datetime, int connectionTime) {
 
-    return p->route(start, dest, datetime);
+    return p->route(start, dest, datetime, connectionTime);
 
 }
 
