@@ -25,7 +25,7 @@ public:
 
     bool reverseGeoCode(const float x, const float y);
 
-    bool route(FinnishCoordinates start, FinnishCoordinates dest, const QDateTime &datetime);
+    bool route(FinnishCoordinates start, FinnishCoordinates dest, const QDateTime &datetime, int connectionTime);
 
     Route::List routeResults();
 
