@@ -33,7 +33,7 @@ public:
 
     bool search(const QString &what);
 
-    bool route(FinnishCoordinates start, FinnishCoordinates dest, const QDateTime &datetime);
+    bool route(FinnishCoordinates start, FinnishCoordinates dest, const QDateTime &datetime, int connectionTime);
 
     Location::List searchResults();
 
